@@ -1,11 +1,14 @@
+import datetime as dt
 import json
 import gql
 import ast
+import socket
 from gql.transport.requests import RequestsHTTPTransport
 import urllib3; urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 import pandas as pd
 from polity import static
 from polity.static import (
+    CREATE_NEW_USER_MUTATION
     DATASET_NAME_DESC_QUERY,
     COMPANY_CIK_NAME_QUERY,
     COMPANY_CIK_TICKER_QUERY,
@@ -61,6 +64,15 @@ class Client():
             transport=transport,
             fetch_schema_from_transport=True,
         )
+        # new user 
+
+        hostname = socket.gethostname()
+        ip_addr  = socket.gethostbyname(hostname)
+        current_time = str(dt.datetime.now()))
+
+        graphql.execute(
+            CREATE_NEW_USER_MUTATION(hostname,ip_addr,current_time)
+        )
         return graphql
 
     def _test(self):
