@@ -78,6 +78,12 @@ FINANCIAL_STATEMENT_QUERY = lambda cik, kind, api_key :'''
         }
     }'''%(cik,api_key,kind)
 
+CREATE_NEW_USER_MUTATION = lambda email, name, photoUrl : '''
+    mutation{
+    createUser(email:"%s",name:"%s",photoUrl:"%s"){ok}
+    }
+    '''%(email,name,photoUrl)
+
 def take_a_sec():
     print('  - this could take a sec...')
 
